Struct pallet_gilt::pallet::ActiveGiltsTotal [−][src]
pub struct ActiveGiltsTotal<Balance> {
pub frozen: Balance,
pub proportion: Perquintill,
pub index: ActiveIndex,
pub target: Perquintill,
}Expand description
Overall information package on the active gilts.
The way of determining the net issuance (i.e. after factoring in all maturing frozen funds) is:
issuance - frozen + proportion * issuance
where issuance = total_issuance - IgnoredIssuance
Fields
frozen: BalanceThe total amount of funds held in reserve for all active gilts.
proportion: PerquintillThe proportion of funds that the frozen balance represents to total issuance.
index: ActiveIndexThe total number of gilts issued so far.
target: PerquintillThe target proportion of gilts within total issuance.